==> agr-center-domain-3.1.0-CLOUD-DEV-20230201.103408-6-sources.jar: com/tydic/dyc/agr/model/agrhis/AgrAgrHisDo.java <==
package com.tydic.dyc.agr.model.agrhis;

import lombok.Data;
import java.io.Serializable;
import com.tydic.dyc.agr.model.agrhis.sub.AgrItemHis;
import com.tydic.dyc.agr.model.agrhis.sub.AgrAppScopeHis;
import com.tydic.dyc.agr.model.agrhis.sub.AgrPayConfigHis;
import com.tydic.dyc.agr.model.agrhis.sub.AgrAdjustCfgHis;
import com.tydic.dyc.agr.model.agrhis.sub.AgrCataScopeHis;
import com.tydic.dyc.agr.model.agrhis.sub.AgrRelHis;
import com.tydic.dyc.agr.model.agrhis.sub.AgrMainExtHis;
import java.util.Date;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-02-01 18:09
 **/
@Data
public class AgrAgrHisDo implements Serializable {
	private static final long serialVersionUID =  -6277796209131963836L;

	/**
	 * 主体历史Id
	 */
	private Long agrMainHisId;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 外部关联编号
	 */
	private String relCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 租户ID
	 */
	private String tenantId;
	/**
	 * 父协议ID
	 */
	private Long parentAgrId;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议状态
	 */
	private Integer agrStatus;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 铺货方式
	 */
	private Integer vendorMode;
	/**
	 * 是否配送
	 */
	private Integer whetherDispatch;
	/**
	 * 是否分配
	 */
	private Integer whetherAssign;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 管理单位ID
	 */
	private Long managementOrgId;
	/**
	 * 管理单位名称
	 */
	private String managementOrgName;
	/**
	 * 采购单位ID
	 */
	private Long purchaseOrgId;
	/**
	 * 采购单位名称
	 */
	private String purchaseOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 结算单位ID
	 */
	private Long settlementOrgId;
	/**
	 * 结算单位名称
	 */
	private String settlementOrgName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 质保期单位
	 */
	private String quaprotectUnit;
	/**
	 * 质保期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期(月)
	 */
	private Integer warantty;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 调价机制
	 */
	private Integer adjustPrice;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 经办人用户名
	 */
	private String agrOperatorUsername;
	/**
	 * 编制人名称
	 */
	private String createName;
	/**
	 * 编制人用户名
	 */
	private String createUsername;
	/**
	 * 编制人ID
	 */
	private Long createLoginId;
	/**
	 * 编制时间
	 */
	private Date createTime;
	/**
	 * 编制人单位
	 */
	private Long createOrgId;
	/**
	 * 编制人单位名称
	 */
	private String createOrgName;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议明细历史
	 */
	private List<AgrItemHis> agrItemHis;
	/**
	 * 协议应用范围历史
	 */
	private List<AgrAppScopeHis> agrAppScopeHis;
	/**
	 * 协议支付配置历史
	 */
	private List<AgrPayConfigHis> agrPayConfigHis;
	/**
	 * 协议调价配置历史
	 */
	private AgrAdjustCfgHis agrAdjustCfgHis;
	/**
	 * 协议类目范围历史
	 */
	private List<AgrCataScopeHis> agrCataScopeHis;
	/**
	 * 协议外部关联历史
	 */
	private List<AgrRelHis> agrRelHis;
	/**
	 * 协议主体拓展历史
	 */
	private List<AgrMainExtHis> agrMainExtHis;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> agr-center-domain-3.3.0-CLOUD-DEV-20250212.060224-1-sources.jar: com/tydic/dyc/agr/model/agrhis/AgrAgrHisDo.java <==
package com.tydic.dyc.agr.model.agrhis;

import lombok.Data;
import java.io.Serializable;
import com.tydic.dyc.agr.model.agrhis.sub.AgrItemHis;
import com.tydic.dyc.agr.model.agrhis.sub.AgrAppScopeHis;
import com.tydic.dyc.agr.model.agrhis.sub.AgrPayConfigHis;
import com.tydic.dyc.agr.model.agrhis.sub.AgrAdjustCfgHis;
import com.tydic.dyc.agr.model.agrhis.sub.AgrCataScopeHis;
import com.tydic.dyc.agr.model.agrhis.sub.AgrRelHis;
import com.tydic.dyc.agr.model.agrhis.sub.AgrMainExtHis;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-02-08 12:04
 **/
@Data
public class AgrAgrHisDo implements Serializable {
	private static final long serialVersionUID =  -9133116527011335275L;

	/**
	 * 主体历史Id
	 */
	private Long agrMainHisId;
	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 外部关联编号
	 */
	private String relCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 租户ID
	 */
	private String tenantId;
	/**
	 * 父协议ID
	 */
	private Long parentAgrId;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议状态
	 */
	private Integer agrStatus;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 铺货方式
	 */
	private Integer vendorMode;
	/**
	 * 是否配送
	 */
	private Integer whetherDispatch;
	/**
	 * 是否分配
	 */
	private Integer whetherAssign;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 管理单位ID
	 */
	private String managementOrgId;
	/**
	 * 管理单位名称
	 */
	private String managementOrgName;
	/**
	 * 采购单位ID
	 */
	private Long purchaseOrgId;
	/**
	 * 采购单位名称
	 */
	private String purchaseOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 结算单位ID
	 */
	private Long settlementOrgId;
	/**
	 * 结算单位名称
	 */
	private String settlementOrgName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 质保期单位
	 */
	private String quaprotectUnit;
	/**
	 * 质保期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期(月)
	 */
	private Integer warantty;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 是否有明细标识
	 */
	private Integer whetherHaveItem;

	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 调价机制
	 */
	private Integer adjustPrice;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 经办人用户名
	 */
	private String agrOperatorUsername;
	/**
	 * 编制人名称
	 */
	private String createName;
	/**
	 * 编制人用户名
	 */
	private String createUsername;
	/**
	 * 编制人ID
	 */
	private Long createLoginId;
	/**
	 * 编制时间
	 */
	private Date createTime;
	/**
	 * 编制人单位
	 */
	private Long createOrgId;
	/**
	 * 编制人单位名称
	 */
	private String createOrgName;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议明细历史
	 */
	private List<AgrItemHis> agrItemHis;
	/**
	 * 协议应用范围历史
	 */
	private List<AgrAppScopeHis> agrAppScopeHis;
	/**
	 * 协议支付配置历史
	 */
	private List<AgrPayConfigHis> agrPayConfigHis;
	/**
	 * 协议调价配置历史
	 */
	private AgrAdjustCfgHis agrAdjustCfgHis;
	/**
	 * 协议类目范围历史
	 */
	private List<AgrCataScopeHis> agrCataScopeHis;
	/**
	 * 协议外部关联历史
	 */
	private List<AgrRelHis> agrRelHis;
	/**
	 * 协议主体拓展历史
	 */
	private List<AgrMainExtHis> agrMainExtHis;
	/**
	 * 含税金额
	 */
	private BigDecimal taxAmount;
	/**
	 * 税率
	 */
	private String taxRate;
	/**
	 * 编制人联系方式
	 */
	private String createNameContact;
	/**
	 * 签约方数量
	 */
	private String signatoryNum;
	/**
	 * 扩展字段1
	 */
	private String agrMainExtend1;
	/**
	 * 扩展字段2
	 */
	private String agrMainExtend2;
	/**
	 * 扩展字段3
	 */
	private String agrMainExtend3;
	/**
	 * 扩展字段4
	 */
	private String agrMainExtend4;
	/**
	 * 扩展字段5
	 */
	private String agrMainExtend5;
	/**
	 * 扩展字段6
	 */
	private String agrMainExtend6;
	/**
	 * 扩展字段7
	 */
	private String agrMainExtend7;
	/**
	 * 扩展字段8
	 */
	private String agrMainExtend8;
	/**
	 * 扩展字段9
	 */
	private String agrMainExtend9;
	/**
	 * 扩展json
	 */
	private String agrMainExtendJson;
	/**
	 * 外部关联ID
	 */
	private String relId;
	/**
	 * 外部关联名称
	 */
	private String relName;
	/**
	 * 协议来源ID
	 */
	private String agrSrcId;
	/**
	 * 不含税金额
	 */
	private BigDecimal noTaxAmount;
	/**
	 * 排序
	 */
	private String orderBy;

}
